%
%  y=Gregmult(x)
%
% This computes the products
%
%   y=[G; alpha*L]*x
%
% and 
%
%  y=[G' alpha*L')*x
%
% Required by LSQR to solve the least squares problem
%
% min norm(G*m-d)^2+norm(L*m)^2
%
% Here, the G, L, G' (stored as GT), and L' (stored as LT) matrices
% are stored as global variables.  
%
function y=Gregmult4(x,trans)
%
% Global variables hold G, L, and their transposes, plus alpha.
%
global G;
global GT;
global L;
global LT;
global alpha;
%
% See if LSQR wants to do a regular multiplication or a transposed 
% multiplication.
%
if (strcmp(trans,'notransp'))
%
% A regular multiplication.
%
  y=[G*x; alpha*(L*x)];
 else
%
% A transposed multiplication.
%
  [p,q]=size(G);
  [r,s]=size(L);
  y=GT*x(1:p)+alpha*(LT*x(p+1:p+r));
end


