%
% d=diagestrand(matvecmult,n,s)
%
% This function uses the algorithm of Bekas et al. to estimate the diagonal
% of a square matrix, where the matrix is not given explicitly, but instead
% we have a function for computing matrix vector productions.
%
% Inputs:
%   matvecmult            The handle for a function that does multiplications
%   n                     The dimension of the matrix.
%   s                     The number of random test vectors to use.
%
% Output:
%   d                     The estimated diagonal of the matrix
%
function d=diagestrand(matvecmult,n,s)
%
% First, generate the random test vectors.
%
V=randn(n,s);
%
% Now, do the actual estimation of the diagonal.
%
d=zeros(n,1);
t=d;
q=d;
for k=1:s
%
% Uncomment the following line if you'd like to monitor the progress of this 
% loop.
%   k
%
  v=V(:,k);
  t=t+matvecmult(v).*v;
  q=q+(v.*v);
  d=t./q;  
end

