%
% This script produces the L-curve and GCV function for our example problem.
%
% First, clear memory and reset the RNG's, so we get consistent results.
%
clear
rand('state',0);
randn('state',0);
%
% Load in the problem data.  
%
load example.mat
%
% Setup G' and L';
%
global alpha;
global GT;
global LT;
GT=G';
LT=L';
%
% Setup a range of values of the regularization parameter alpha.
%
alphas=[0.01; 0.03; 0.05; 0.07; 0.1; 0.3; 0.5; 0.7; 1.0; 3;  5; ...
	 7; 10.0; 30; 50; 70;  100.0];
%
% Allocate space for the function outputs.
%
normgmd=zeros(size(alphas));
normlm=zeros(size(alphas));
v0=zeros(size(alphas));
%
% Loop through the values of alpha, computing the GCV function for each one.
%
for k=1:length(alphas);
%
% Compute the GCV function, norm(G*mreg-d), and norm(L*mreg).
%
  [v0(k),num,denom,normgmd(k),normlm(k)]=gcv(alphas(k));
%
% Print out the results for this point.
%
  fprintf('alpha=%f, norm(G*m-d)=%f, norm(L*m)=%f, G(alpha)=%f\n',...
	  [alphas(k); normgmd(k); normlm(k); v0(k)]);
end
%
% Save the results for later analysis.
%
save lcurve.mat

