%
% [v,num,denom,normgmd,normlm]=gcv(a)
%
% Computes the generalized cross validation function for a given value, a, of 
% the regularization parameter, using the stochastic approach of Bekas et al.
% to estimate the required trace. 
%
% The first returned value, v0, is the value of the GCV function.  The second 
% and third returned values are the numerator and denominator of 
% the fraction that is v0.  The fourth and fifth returned values give  
% norm(G*m-d) and norm(L*m).
%
function [v0,num,denom,normgmd,normlm]=gcv(a)
%
% Global variables used within this function.
%
global alpha;
global G;
global L;
global d;
%
% Set alpha.
%
alpha=a;
%
% Get the size of G and L. 
%
[m,n]=size(G);
[r,s]=size(L);
%
% First, compute the regularized solution.
%
dpad=sparse([d; zeros(r,1)]);
mreg=lsqr(@Gregmult,dpad,[],5000);
%
% Compute norm(G*mreg-d) and norm(L*mreg) for use in the L-curve if desired.
%
normgmd=norm(G*mreg-d);
normlm=norm(L*mreg);
%
% The numerator is norm(G*mreg-d)^2;
%
num=norm(G*mreg-d,2)^2;
%
% Now, work on the denominator.
%
numvecs=256;
diag=diagestrand(@IGGmult,m,numvecs);
%
% Now, compute the denominator.
%
denom=sum(diag)^2;
%
% Put the numerator and denominator together to get v0.
%
v0=m*num/denom;
