% Resolution comparison for a 512-block cube tomography example

% make sure we have a clean environment
clear
rand('state',0);
randn('state',0);
% Load in the problem data.
load data_512.mat
GT = G';
LT = L';
alpha = 0.5;
% set up the variables we will want to be global
global GT;
global G;
global L;
global LT;
global alpha;

% Some size parameters.
[m,n]=size(G);


%evaluate the formal resolution matrix using the Tikhonov regularization
%model resolution formula from Parameter Estimation and Inverse Problems
Gsharp=(GT*G+alpha^2*LT*L)\GT;
Rm=Gsharp*G;

% stochastically estimate the resolution diagonal
% Repeat the process of estimating the diagonal ntimes
ntimes=20;
diags=zeros(ntimes,n);
for k=1:ntimes
  % Use 256 random vectors for each estimate
  numcols=256;
  fprintf('Starting diagonal estimation %d\n',k);

  % Estimate the diagonal of R.
  diagR=diagestrand(@Rmult_512,n,numcols);

  % Store the estimate.  
  diags(k,:)=diagR';
end

% Find the median of the estimates
diagR=median(diags);


save synthetic.mat
